==> LPStimeSeries_1.0.tar.gz: LPStimeSeries/R/computeSimilarity.R <==
computeSimilarity <- function(object=NULL,testseries=NULL,refseries=NULL,maxdepth=NULL,
						terminal=TRUE,testrepresentation,refrepresentation) {

  if(!is.null(object)){
	  if (!inherits(object, "learnPattern"))
			stop("object not of class learnPattern")
	  if (is.null(object$forest)) stop("No forest component in the object")
	  if (is.null(refseries) && is.null(testseries)) stop("You need to provide two time series data sets for similarity computation")
	  terminal=FALSE
  }
  
  if(terminal){ #if computation will be performed over representations
	  ntest=nrow(testrepresentation)
	  ntrain=nrow(refrepresentation)
	  nofterminal=ncol(refrepresentation)
	  ans <- .C("compute_similarity", 
				as.integer(as.matrix(testrepresentation)), 
				as.integer(ntest), 
				as.integer(as.matrix(refrepresentation)),  
				as.integer(ntrain), 
				as.integer(nofterminal), 
				result=integer(ntest*ntrain))
	  return(matrix(ans$result,ntest,ntrain))
	  
  } else {	 #if computation will be performed over raw time series
    if(is.null(maxdepth)) maxdepth=object$maxdepth
    if(maxdepth>object$maxdepth) {
		maxdepth=object$maxdepth
		warning("invalid depth: reset to the maximum depth provided during training!")
    }
	mdim <- ncol(refseries)
	ntree <- object$forest$ntree
	ntrain <- nrow(refseries)
	ntest <- nrow(testseries)
	keepIndex <- c("similarity")
	x <- t(data.matrix(refseries))
	xtst <- t(data.matrix(testseries))
	ans <- .C("regForest_similarity",
			as.double(x),
			as.double(xtst),
		    as.integer(ntrain),
			as.integer(ntest),
			as.double(object$segment.length),
		    as.integer(mdim),
			as.integer(object$ntree),
			object$forest$leftDaughter,
			object$forest$rightDaughter,
			object$forest$nodestatus,
			object$forest$nodedepth,
			object$forest$nrnodes,
			object$forest$xbestsplit,
			object$forest$bestvar,
			object$forest$splitType,
			object$forest$ndbigtree,
			as.integer(maxdepth),
			similarity = integer(ntest*ntrain),
			PACKAGE = "LPStimeSeries")[keepIndex]
	}
	return(matrix(ans$similarity,ntest,ntrain))
}

==> LPStimeSeries_1.0-1.tar.gz: LPStimeSeries/R/computeSimilarity.R <==
computeSimilarity <- function(object=NULL,testseries=NULL,refseries=NULL,maxdepth=NULL,
						terminal=TRUE,testrepresentation,refrepresentation) {

  if(!is.null(object)){
	  if (!inherits(object, "learnPattern"))
			stop("object not of class learnPattern")
	  if (is.null(object$forest)) stop("No forest component in the object")
	  if (is.null(refseries) && is.null(testseries)) stop("You need to provide two time series data sets for similarity computation")
	  terminal <- FALSE
  }
  
  if(terminal){ #if computation will be performed over representations
	  ntest <- nrow(testrepresentation)
	  ntrain <- nrow(refrepresentation)
	  nofterminal <- ncol(refrepresentation)
	  ans <- .C("compute_similarity", 
				as.integer(as.matrix(testrepresentation)), 
				as.integer(ntest), 
				as.integer(as.matrix(refrepresentation)),  
				as.integer(ntrain), 
				as.integer(nofterminal), 
				result=integer(ntest*ntrain))
	  return(matrix(ans$result,ntest,ntrain))
	  
  } else {	 #if computation will be performed over raw time series
    if(is.null(maxdepth)) maxdepth <- object$maxdepth
    if(maxdepth>object$maxdepth) {
		maxdepth <- object$maxdepth
		warning("invalid depth: reset to the maximum depth provided during training!")
    }
	mdim <- ncol(refseries)
	ntree <- object$forest$ntree
	ntrain <- nrow(refseries)
	ntest <- nrow(testseries)
	keepIndex <- c("similarity")
	x <- t(data.matrix(refseries))
	xtst <- t(data.matrix(testseries))
	ans <- .C("regForest_similarity",
			as.double(x),
			as.double(xtst),
		    as.integer(ntrain),
			as.integer(ntest),
			as.double(object$segment.length),
		    as.integer(mdim),
			as.integer(object$ntree),
			object$forest$leftDaughter,
			object$forest$rightDaughter,
			object$forest$nodestatus,
			object$forest$nodedepth,
			object$forest$nrnodes,
			object$forest$xbestsplit,
			object$forest$bestvar,
			object$forest$splitType,
			object$forest$ndbigtree,
			as.integer(maxdepth),
			similarity = integer(ntest*ntrain),
			PACKAGE = "LPStimeSeries")[keepIndex]
	}
	return(matrix(ans$similarity,ntest,ntrain))
}
